@@ -1,7 +1,8 @@
 from typing import Tuple
-import tomllib
 from functools import lru_cache
 
+import tomli as tomllib
+
 
 @lru_cache()
 def get_app_info() -> Tuple[str, str, str]:
